/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.jenkins.results.parser.test.clazz.group;

import com.liferay.jenkins.results.parser.JenkinsResultsParserUtil;
import com.liferay.jenkins.results.parser.PortalTestClassJob;

import java.io.File;
import java.io.IOException;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Leslie Wong
 */
public abstract class ModulesBatchTestClassGroup extends BatchTestClassGroup {

	public static class ModulesBatchTestClass extends BaseTestClass {

		protected ModulesBatchTestClass(TestClassFile moduleBaseDir) {
			super(moduleBaseDir);
		}

		protected void initTestClassMethods(
			List<File> modulesProjectDirs, File modulesDir, String taskName) {

			for (File modulesProjectDir : modulesProjectDirs) {
				String path = JenkinsResultsParserUtil.getPathRelativeTo(
					modulesProjectDir, modulesDir);

				String moduleTaskCall = JenkinsResultsParserUtil.combine(
					":", path.replaceAll("/", ":"), ":", taskName);

				addTestClassMethod(moduleTaskCall);
			}
		}

	}

	protected ModulesBatchTestClassGroup(
		String batchName, PortalTestClassJob portalTestClassJob) {

		super(batchName, portalTestClassJob);

		try {
			File modulesDir = new File(
				portalGitWorkingDirectory.getWorkingDirectory(), "modules");

			String upstreamBranchName =
				portalGitWorkingDirectory.getUpstreamBranchName();

			if (upstreamBranchName.startsWith("ee-") ||
				upstreamBranchName.endsWith("-private")) {

				excludesPathMatchers.addAll(
					getPathMatchers(
						getFirstPropertyValue("modules.excludes.private"),
						modulesDir));

				includesPathMatchers.addAll(
					getPathMatchers(
						getFirstPropertyValue("modules.includes.private"),
						modulesDir));
			}
			else {
				excludesPathMatchers.addAll(
					getPathMatchers(
						getFirstPropertyValue("modules.excludes.public"),
						modulesDir));

				includesPathMatchers.addAll(
					getPathMatchers(
						getFirstPropertyValue("modules.includes.public"),
						modulesDir));
			}

			String includedModulesRequired = getFirstPropertyValue(
				"modules.includes.required");

			if (includedModulesRequired != null) {
				for (String requiredModule :
						includedModulesRequired.split(",")) {

					moduleDirsList.add(new File(modulesDir, requiredModule));
				}
			}

			setTestClasses();

			setAxisTestClassGroups();
		}
		catch (IOException ioe) {
			throw new RuntimeException(ioe);
		}
	}

	protected abstract void setTestClasses() throws IOException;

	protected List<File> moduleDirsList = new ArrayList<>();

}